# AstroCats Development README #

## Structure and Code Style ##

Unless otherwise noted, everything should be
[PEP8](https://www.python.org/dev/peps/pep-0008) compliant, with 79 characters
maximum per line (we ignore the 72 character docstring maximum).  Please make
variable names descriptive, and add comments describing *everything*.  Avoid
the use of literals whenever possible - using/defining/documenting constants
appropriately.

## Naming Conventions ##
-   Directories: `lowercase`,  
-   Files: `lowercase`  
-   Classes: `TitleCase`  
-   Variables: `lower_case` (i.e. underscores for breaks/spaces)
    -   Constants: `UPPER_CASE`
